*Replication file for:
*Title: "When Leaders Matter: Rebel Experience and Nuclear Proliferation"
*Authors: Matthew Fuhrmann and Michael C. Horowitz
*Journal: Journal of Politics

* This is a Stata replication file for "When Leaders Matter: Rebel Experience and Nuclear Proliferation." It replicates the regressions, charts, and robustness checks described in the original article and in the Appendix.
* The dataset used to run this file is "FH Dataset 2014-0519.dta."
* Last updated: June 6, 2014

*Change the directory and call up the dataset
cd "/Users/matthewfuhrmann/Dropbox/Leaders and Proliferation/JOP Files 2014-0516"
use "Replication Files/FH Dataset 2014-0519.dta", clear

****************************************************************************************************************************************************************
****************************************************************************************************************************************************************
*Published Paper: Tables and Figures  
****************************************************************************************************************************************************************
****************************************************************************************************************************************************************

****************************************************************************************************************************************************************
*Table 1: List of leaders who pursued nuclear weapons
****************************************************************************************************************************************************************
list leadername year rebel if pursuit==1

****************************************************************************************************************************************************************
*Table 2: logit Analysis of Rebel Experience and Nuclear Weapons Pursuit
****************************************************************************************************************************************************************
logit pursuit rebel nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model1
logit pursuit rebel fiveyear irregular polity2 total nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model2 
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model3
logit pursuit rebel irregular fiveyear polity2 spally  NCA67  lngdpcap npt openness rivalry disputes nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model4

esttab using table1.tex, replace label se nodepvars  star(+ 0.10 * 0.05 ** .01 *** .001) nogaps ///
title(Regression table\label{tab1})

*Substantive effects
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
prvalue , x(rebel 0 irregular 0 fiveyear 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0 ) bootstrap
prvalue , x(rebel 1 irregular 0 fiveyear 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0 ) bootstrap
prvalue , x(polity2 0 irregular 0 fiveyear 0 rebel 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prvalue , x(polity2 8 irregular 0 fiveyear 0 rebel 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prvalue , x(total 5 irregular 0 fiveyear 0 rebel 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prvalue , x(total 8 irregular 0 fiveyear 0 rebel 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prtab spally, x(fiveyear 0 irregular 0 rebel 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prvalue , x(NCA67 2 irregular 0 fiveyear 0 rebel 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prvalue , x(NCA67 6 irregular 0 fiveyear 0 rebel 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prvalue , x(openness 49.76 irregular 0 fiveyear 0 rebel 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prvalue , x(openness 91.34 irregular 0 fiveyear 0 rebel 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prtab npt, x(irregular 0 fiveyear 0 rebel 0 spally 0 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)

****************************************************************************************************************************************************************
*Table 3: Robustness checks
****************************************************************************************************************************************************************
eststo clear
*Country fixed effects
xi: logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  i.ccode if year<2001, cluster(leadid30)
eststo model5
*Matching
drop if irregular==.
drop if fiveyear==.
drop if polity2==.
drop if spally==.
drop if NCA67==.
drop if total==.
drop if lngdpcap==.
drop if npt==.
drop if openness==.
drop if rebel==.
*Additional variables for matching analysis
gen long cntryer=((ccode*10000)+year)
la var cntryer "ID - country year"
sort cntryer 
by cntryer: g long cntryer1=cntryer[_n-1]
by cntryer: egen maxtenyr=max(yearlyduration)
cem irregular fiveyear polity2 total lngdpcap, treatment(rebel)
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap  npt openness nonpuryrs*  [iweight=cem_weights] if year<2001 & maxtenyr==yearlyduration, cluster(leadid30)
eststo model6
use "Replication Files/FH Dataset 2014-0519.dta", clear
*Initation as DV
logit initiation  rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness  noninityrs* [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model7
*One observation per leader
g timeinoffice= enddate-startdate
replace timeinoffice=timeinoffice/365
logit pursuit_avg rebel_avg irregular_avg fiveyear_avg polity2_avg total_avg spally_avg NCA67_avg lngdpcap_avg npt_avg openness_avg timeinoffice if place_holder==. , cluster(ccode)
eststo model8
*Personalistic regimes
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness WeeksPersonalist nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model9
*Irregular =  0
logit pursuit rebel fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if irregular==0 & year<2001, cluster(leadid30)
eststo model10

esttab using table3.tex, replace label se nodepvars  star(+ 0.10 * 0.05 ** .01 *** .001) nogaps ///
title(Regression table\label{tab3})

****************************************************************************************************************************************************************
*Figure 1: Rebel Experience and Nuclear Weapons Pursuit
****************************************************************************************************************************************************************
tab pursuit rebel if year>1944 & year<1960, column chi2
tab pursuit rebel if year>1959 & year<1970, column chi2
tab pursuit rebel if year>1969 & year<1980, column chi2
tab pursuit rebel if year>1979 & year<1990, column chi2
tab pursuit rebel if year>1989 & year<2001, column chi2

****************************************************************************************************************************************************************
*Figure 2: Substantive Effects of Rebel Experience on Nuclear Weapons Pursuit (based on M3)
****************************************************************************************************************************************************************
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
prvalue , x(rebel 0 irregular 0 fiveyear 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0 ) bootstrap
prvalue , x(rebel 1 irregular 0 fiveyear 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0 ) bootstrap

****************************************************************************************************************************************************************
****************************************************************************************************************************************************************
*Online Appendix: Tables and Figures  
****************************************************************************************************************************************************************
****************************************************************************************************************************************************************

****************************************************************************************************************************************************************
*Table A: Cross-tabulation of Rebel Experience and Nuclear Proliferation
****************************************************************************************************************************************************************
tab pursuit rebel, column chi2

****************************************************************************************************************************************************************
*Table B: Cross-tabulation of Rebel Experience and Entry into Office
****************************************************************************************************************************************************************
tab  irregular rebel, column chi2

****************************************************************************************************************************************************************
*Table C: Cross-tabulation of Rebel Experience andPersonalistic Regimes
****************************************************************************************************************************************************************
tab rebel WeeksPersonalist if pursuit==1, chi2 column

****************************************************************************************************************************************************************
*Table D: Cross-tabulation of Rebel Experience and Revolutionary Leaders
****************************************************************************************************************************************************************
tab rebel revolutionary if pursuit==1, chi2 column

****************************************************************************************************************************************************************
*Table E
****************************************************************************************************************************************************************
eststo clear
*DV: bomb program (including post-acquisition)
logit bombprgm  rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness   nonbombyrs* [iweight=yearlyduration], cluster(leadid30)
eststo model1
*Use Jo and Gartzke DV coding
logit pursuitjg  rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness  nonjgyrs* [iweight=yearlyduration], cluster(leadid30)
eststo model2
*Use modified Singh and Way coding
logit pursuitsw rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonswyrs* [iweight=yearlyduration], cluster(leadid30)
eststo model3
*DV: explore
logit explore  rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness  nonexpyrs* [iweight=yearlyduration], cluster(leadid30)
eststo model4

esttab using tableE.tex, replace label se nodepvars  star(+ 0.10 * 0.05 ** .01 *** .001) nogaps  ///
title(Regression table\label{tabE})

***********************************************************************************************************************************************************************************
*Table F
***********************************************************************************************************************************************************************************
eststo clear
*Rebel lag test
logit pursuit rebel rebellag rebellagrebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model5
prvalue , x(rebel 0 rebellag 0 rebellagrebel 0 irregular 0 fiveyear 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
prvalue , x(rebel 1 rebellag 0 rebellagrebel 0 irregular 0 fiveyear 0 spally 0 npt 1 nonpuryrs 0 nonpuryrs2 0 nonpuryrs3 0)
*Post-NPT model
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year>1969 & year<2001, cluster(leadid30)
eststo model6
*Interact rebel and alliance with superpower
g rebelXspally=rebel*spally
logit pursuit rebel rebelXspally irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model7
*Add military capabilities
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness cap nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model8
*Add cold war dummy
gen coldwar=0
replace coldwar=1 if year>=1945 & year<=1990
logit pursuit  rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness coldwar nonpuryrs* [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model9
*Alliance with any nuclear power (as opposed to just superpowers)
logit pursuit rebel irregular fiveyear polity2 total allies  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model10
*Rare events logit
relogit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model11
*Stable states excluded
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001 & revbkgnd_alt==1, cluster(leadid30)
eststo model12
*Exclude cases with gdp per capita lower than the smallest economy to initiate a weapons program
logit pursuit  rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if gdpcap>675, cluster(leadid30)
eststo model13

esttab using tableF.tex, replace label se nodepvars  star(+ 0.10 * 0.05 ** .01 *** .001) nogaps ///
title(Regression table\label{taba5})
eststo clear


***********************************************************************************************************************************************************************
*Table G
***********************************************************************************************************************************************************************
eststo clear
*Add military service
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness milservice nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model14
g anymil=0
replace anymil=1 if rebel==1
replace anymil=1 if milservice==1
logit pursuit anymil irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model15
*Cluster the standard errors by country
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(ccode)
eststo model16
*Exclude Yugoslavia and France
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001 & ccode~=220 & ccode~=345, cluster(leadid30)
eststo model17
*Use polity dummies
g democracy=0
replace democracy=1 if polity2>5 & polity2~=.
replace democracy=. if polity2==.
logit pursuit rebel irregular fiveyear democracy total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model18
g autocracy=0
replace autocracy=1 if polity2<-5 & polity2~=.
replace autocracy=. if polity2==.
logit pursuit rebel irregular fiveyear autocracy total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model19
*Non-revolutionary leaders
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*   [iweight=yearlyduration] if revolutionary==0 & year<2001, cluster(leadid30)
eststo model20
*Control for revolutionary leaders
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness revolutionary nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
eststo model21
*Exclude personalist regimes
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*   [iweight=yearlyduration] if WeeksPersonalist==0 & year<2001, cluster(leadid30)
eststo model22

esttab using tableG.tex, replace label se nodepvars  star(+ 0.10 * 0.05 ** .01 *** .001) nogaps ///
title(Regression table\label{taba6})

***********************************************************************************************************************************************************************
*Figure A.1
***********************************************************************************************************************************************************************
*ROC curve (receiver operating characteristic)
logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
lroc
*Findings indicate that if a proliferator and a nonproliferator were chosen at random, there is a 96 percent probability that the proliferator has a higher predicted probability than the nonproliferator.

permute rebel "logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs* if year<2001, cluster(leadid30)" _b, reps(10000)
permute rebel x2=e(chi2), reps(1000): logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  [iweight=yearlyduration] if year<2001, cluster(leadid30)
permute rebel e(chi2), reps(100): logit pursuit rebel irregular fiveyear polity2 total spally  NCA67  lngdpcap npt openness nonpuryrs*  if year<2001, cluster(leadid30)

